@@ -119,6 +119,15 @@ class User:
         }
         return s.post('https://www.luogu.com.cn/api/chat/new',headers=headers,data=postData).json()
         
+    def getLastCode(self,pid):
+        s=self.sess
+        if(not s):
+            print('请先登录!')
+            return
+        r=s.get('https://www.luogu.com.cn/problem/'+pid,headers=headers)
+        res=json.loads(unquote(re.findall('JSON.parse\(decodeURIComponent\("(.*?)"\)\);',r.text)[0]))['currentData']
+        return {'lastLanguage':res['lastLanguage'],'lastCode':res['lastCode']}
+    
 def getUid(name):
     r=requests.get('https://www.luogu.com.cn/api/user/search?keyword='+name,headers=headers).json()
     if(r['users'][0]):
@@ -126,10 +135,28 @@ def getUid(name):
     else:
         return '-1'
         
-def searchProblem(keyword,page,diffi=0):
+def searchProblem(keyword,page,diffi=-1):
     r=requests.get('https://www.luogu.com.cn/problem/list?keyword='+keyword+('&difficulty='+str(diffi) if diffi!=-1 else '')+'&page='+str(page)+'&_contentOnly=1',headers=headers)
     return r.json()['currentData']
     
 def getContestList(page):
     r=requests.get('https://www.luogu.com.cn/contest/list?page='+str(page)+'&_contentOnly=1',headers=headers)
-    return r.json()['currentData']['contests']
\ No newline at end of file
+    return r.json()['currentData']['contests']
+    
+def loginWithCookie(client_id,uid):
+    s=requests.session()
+    requests.utils.add_dict_to_cookiejar(s.cookies,{'__client_id':client_id,'_uid':str(uid)})
+    res=User('*','*')
+    res.sess=s
+    print('验证cookie有效性...')
+    if(res.getUserData()):
+        print('登录成功!')
+        print('用户uid: '+uid)
+        return res
+    else:
+        print('该cookie无效!')
+        return None
+    
+def getProblemInfo(pid):
+    r=requests.get('https://www.luogu.com.cn/problem/'+pid,headers=headers)
+    return json.loads(unquote(re.findall('JSON.parse\(decodeURIComponent\("(.*?)"\)\);',r.text)[0]))['currentData']['problem']
\ No newline at end of file
